=== modified file 'NEWS'
--- NEWS	2005-11-18 08:10:07 +0000
+++ NEWS	2005-11-21 08:51:56 +0000
@@ -5,6 +5,11 @@
     * .bzrignore is excluded from exports, on the grounds that it's a bzr 
       internal-use file and may not be wanted.  (Jamie Wilkinson)
 
+    * The "bzr directories" command were removed in favor of the new
+      --kind option to the "bzr inventory" command.  To list all 
+      versioned directories, now use "bzr inventory --kind directory".  
+      (Johan Rydberg)
+
   IMPROVEMENTS:
 
     * "bzr INIT dir" now initializes the specified directory, and creates 

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-11-17 08:07:57 +0000
+++ bzrlib/builtins.py	2005-11-21 08:51:56 +0000
@@ -260,11 +260,17 @@
 
 
 class cmd_inventory(Command):
-    """Show inventory of the current working copy or a revision."""
-    takes_options = ['revision', 'show-ids']
+    """Show inventory of the current working copy or a revision.
+
+    It is possible to limit the output to a particular entry
+    type using the --kind option.  For example; --kind file.
+    """
+    takes_options = ['revision', 'show-ids', 'kind']
     
     @display_command
-    def run(self, revision=None, show_ids=False):
+    def run(self, revision=None, show_ids=False, kind=None):
+        if kind and kind not in ['file', 'directory', 'symlink']:
+            raise BzrCommandError('invalid kind specified')
         b = Branch.open_containing('.')[0]
         if revision is None:
             inv = b.working_tree().read_working_inventory()
@@ -275,6 +281,8 @@
             inv = b.get_revision_inventory(revision[0].in_history(b).rev_id)
 
         for path, entry in inv.entries():
+            if kind and kind != entry.kind:
+                continue
             if show_ids:
                 print '%-50s %s' % (path, entry.file_id)
             else:
@@ -671,18 +679,6 @@
             print revision_id
 
 
-class cmd_directories(Command):
-    """Display list of versioned directories in this branch."""
-    @display_command
-    def run(self):
-        for name, ie in (Branch.open_containing('.')[0].working_tree().
-                         read_working_inventory().directories()):
-            if name == '':
-                print '.'
-            else:
-                print name
-
-
 class cmd_init(Command):
     """Make a directory into a versioned branch.
 

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2005-10-28 02:34:22 +0000
+++ bzrlib/option.py	2005-11-21 08:51:56 +0000
@@ -200,6 +200,7 @@
 _global_option('remember', help='Remember the specified location as a'
                ' default.')
 _global_option('reprocess', help='Reprocess to reduce spurious conflicts')
+_global_option('kind', type=str)
 
 
 def _global_short(short_name, long_name):

=== modified file 'bzrlib/selftest/blackbox.py'
--- bzrlib/selftest/blackbox.py	2005-11-17 07:45:38 +0000
+++ bzrlib/selftest/blackbox.py	2005-11-21 08:51:56 +0000
@@ -529,6 +529,22 @@
         self.runbzr('pull ../b')
         self.runbzr('pull ../b')
 
+    def test_inventory(self):
+        bzr = self.runbzr
+        def output_equals(value, *args):
+            out = self.runbzr(['inventory'] + list(args), backtick=True)
+            self.assertEquals(out, value)
+
+        bzr('init')
+        open('a', 'wb').write('hello\n')
+        os.mkdir('b')
+
+        bzr('add a b')
+        bzr('commit -m add')
+
+        output_equals('a\n', '--kind', 'file')
+        output_equals('b\n', '--kind', 'directory')        
+
     def test_ls(self):
         """Test the abilities of 'bzr ls'"""
         bzr = self.runbzr

